@@ -8,7 +8,7 @@ use strict;
 
 package XML::Compile::Schema::NameSpaces;
 use vars '$VERSION';
-$VERSION = '1.52';
+$VERSION = '1.54';
 
 
 use Log::Report 'xml-compile', syntax => 'SHORT';
@@ -143,7 +143,7 @@ sub doesExtend($$)
         }
     }
     else
-    {   # build-in
+    {   # built-in
         my ($ns, $local) = unpack_type $ext;
         $ns eq SCHEMA2001 && $builtin_types{$local}
             or error __x"cannot find {type} as simpleType or complexType"
